import requests
import os

class requestHandler:
	actions = {
	'KEY_UP': 'Up',
	'KEY_DOWN': 'Down',
	'KEY_LEFT': 'Left',
	'KEY_RIGHT': 'Right',
	'\n': 'Select',
	'KEY_HOME': 'Home',
	'KEY_BACKSPACE': 'Backspace',
	'\t': 'Info',
	'\x1b': 'Back',
	'+': 'VolumeUp',
	'-': 'VolumeDown',
	'KEY_DC': 'PowerOff'
	}
	# The final three actions are specific to Roku TVs and therefore may not work on some devices

	def sendRequests(keypress, typing, var):
		ip = var
		# Checks environment variable to see if it is set, raises if not set
		try:	
		# filters off user input into typed input and non-typed input and requests accordingly
			if typing == True:
				request = f"http://{ip}:8060/keypress/Lit_{keypress}"
				requests.post(request)
			else:
				request = f"http://{ip}:8060/keypress/{keypress}"
				requests.post(request)	
			return 0
	
		except Exception as e:
			print(e)
			return 1
			# miscellanious exception handling

		
	



import sys
from curtsies import Input
from RokuController import sendHttpRequests
import socket
from pyfiglet import Figlet

def checkValidity(ip):
	try:
		socket.inet_aton(ip)
		return 0
	except socket.error:
		return 1

def main():
	f = Figlet(font='slant')
	print(f.renderText('RokuController'))
	print('\n\n\n')
	if len(sys.argv) != 2:
		raise ValueError("No IP address argument given.")
		exit()
	
	ip = sys.argv[1]
	if checkValidity(ip) == 1:
		raise ValueError("Invalid IP address")
		exit()

	actions = sendHttpRequests.requestHandler.actions
	with Input(keynames='curses') as input_generator:
		for keypress in input_generator:
			print(keypress)
			# Checks to see if keypress is a command or is something that is to be used as user text input
			if keypress not in actions:
				sendHttpRequests.requestHandler.sendRequests(keypress, True, ip)
			else:
				sendHttpRequests.requestHandler.sendRequests(actions[keypress], False, ip)
					
	
if __name__ == '__getuserinput__':
	main()





from distutils.core import setup

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()


setup(
  name = 'RokuController',         
  packages = ['RokuController'],   
  version = '1.0.2beta', 
  license='gpl-2.0',        
  description = 'An easy to use Roku cli interface.',   
  author = 'Levelfourtwenty',                
  author_email = 'level420@protonmail.com',     
  long_description=long_description,
  long_description_content_type="text/markdown",
  include_package_data=True,
  url = 'https://github.com/levelfourtwenty/RokuController/',  
  download_url = 'https://github.com/levelfourtwenty/RokuController/v_1.0.2beta.tar.gz',\
  keywords = ['Controller', 'Roku Cli', 'Roku'],
  install_requires=[            
          'requests',
          'curtsies',
	  'pyfiglet',

      ],
  classifiers=[
    'Development Status :: 4 - Beta',     
    'Intended Audience :: Developers', 
    'Topic :: Utilities',
    'License :: OSI Approved :: GNU General Public License v2 (GPLv2)',  
    'Programming Language :: Python :: 3',  
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Programming Language :: Python :: 3.10',
  ],
    entry_points = {
        'console_scripts': ['rokucontroller=RokuController.getuserinput:main'],
    }
)
